@@ -22,6 +22,7 @@ CommandLine:
 
 
 Example:
+    >>> from torch_liberator.deployer import *
     >>> import torch_liberator
     >>> from torchvision import models
 
@@ -34,6 +35,7 @@ Example:
     >>> zip_fpath = torch_liberator.deploy(model, 'test-deploy.zip')
 
     >>> print('--- LOAD THE DEPLOYED MODEL ---')
+    >>> from torch_liberator.deployer import DeployedModel
     >>> loader = DeployedModel(zip_fpath)
     >>> model = loader.load_model()
 
@@ -61,7 +63,8 @@ def deploy(model, fpath, initkw=None, export_modules=[]):
     Args:
         model (torch.Module): this is a torch model, which ideally is
             statically parsable. The value of modgt
-        fpath (str): file path to the deployfile
+
+        fpath (str): file path to the deployfile to be written
 
         initkw: overwrite model._initkw if it exists, otherwise you must
             specify it here. These are the args used to create the instance of
@@ -308,6 +311,28 @@ class DeployedModel(ub.NiceRepr):
     """
     Can setup an initializer and model from a deployed zipfile or a train path
 
+    TODO:
+        NEEDS TO BE REDESIGNED
+
+        Optional Inputs:
+
+            * Train info metadata files
+
+        Possible Inputs:
+
+            * An model instance
+
+            * An model file and a weights file.
+
+            * An deploy file
+
+        Needs Netharn:
+            * A training dpath (can infer model and weights file from this)
+
+            * A weights file (can infer model file from this)
+
+            * A model file (can infer weights file from this)
+
     CommandLine:
         xdoctest -m torch_liberator.deployer DeployedModel
 
